%%
%% Copyright (C) 2005 Eric Chassande-Mottin, CNRS (France)
%%
%% This program may be freely copied under the terms of the 
%% GNU General Public License (GPL), version 2, or at your 
%% option any later version.
%%


%%  generates signal and noise for computing ROC curves

%%    SNR<0 returns only signal
%%    SNR=0 returns only noise
%%    SNR>0 returns signal + noise

function x=get_signal2(snr);

%% -- define signal size
N=1024;
b=16;
Ns1=65;
Ns2=57;
ml=128;
mu=N-ml;
shift_flag=0;

%% -- compute noise and signal
x=randn(N,1);  
p=randchirp(N,b,Ns1,1,Ns2,ml,mu,shift_flag);
p0=rand*2*pi;
s=cos(p+p0);

if (snr>0)
%% -- scale to SNR, SNR^2=N A^2/(2 SIGMA^2)
  a=sqrt(2/N)*snr;
  x=x+a*s;
elseif (snr<0)
  x=s;
end;

return;
